@@ -15,7 +15,7 @@ class GhMergePrUseCase(gh.GhUseCase):
         """Merge pull requests."""
         github_service_method = "merge_pull_request_from_repo"
         self.call_github_service(github_service_method, github_repo, pr_merge)
-        if pr_merge.delete_branch:
+        if pr_merge.delete_branch and not self.error:
             delete_branch_use_case = dbr.GhDeleteBranchUseCase(
                 self.config_manager, self.github_service
             )
