@@ -4,7 +4,7 @@ from typing import Union
 import git_portfolio.request_objects.issue_list as il
 import git_portfolio.responses as res
 import git_portfolio.use_cases.gh as gh
-import git_portfolio.use_cases.gh_list_issue as li
+import git_portfolio.views as views
 
 
 class GhReopenIssueUseCase(gh.GhUseCase):
@@ -17,9 +17,7 @@ class GhReopenIssueUseCase(gh.GhUseCase):
     ) -> None:
         """Reopen issues."""
         github_service_method = "reopen_issues_from_repo"
-        response = li.GhListIssueUseCase(
-            self.config_manager, self.github_service
-        ).execute(request_object, github_repo)
+        response = views.issues(github_repo, self.github_service, request_object)
         if isinstance(response, res.ResponseSuccess):
             self.call_github_service(github_service_method, github_repo, response.value)
         else:
